@@ -1,3 +1,5 @@
+require 'facter/lsb'
+
 Facter.add(:operatingsystem) do
     confine :kernel => :sunos
     setcode do "Solaris" end
@@ -18,6 +20,16 @@ Facter.add(:operatingsystem) do
             "Mandriva"
         elsif FileTest.exists?("/etc/mandrake-release")
             "Mandrake"
+        elsif FileTest.exists?("/etc/arch-release")
+            "Archlinux"
+        elsif FileTest.exists?("/etc/enterprise-release")
+            if FileTest.exists?("/etc/ovs-release")
+                "OVS"
+            else
+                "OEL"
+            end
+        elsif FileTest.exists?("/etc/arch-release")
+            "Arch"
         elsif FileTest.exists?("/etc/redhat-release")
             txt = File.read("/etc/redhat-release")
             if txt =~ /centos/i
@@ -26,7 +38,16 @@ Facter.add(:operatingsystem) do
                 "RedHat"
             end
         elsif FileTest.exists?("/etc/SuSE-release")
-            "SuSE"
+            txt = File.read("/etc/SuSE-release")
+            if txt =~ /^SUSE LINUX Enterprise Server/i
+                "SLES"
+            elsif txt =~ /^SUSE LINUX Enterprise Desktop/i
+                "SLED"
+            elsif txt =~ /^openSUSE/i
+                "OpenSuSE"
+            else
+                "SuSE"
+            end
         end
     end
 end
