@@ -1,10 +1,10 @@
-Facter.add(:puppetversion, :timeout => 1.5) do
-    setcode {
+Facter.add(:puppetversion) do
+    setcode do
         begin
             require 'puppet'
             Puppet::PUPPETVERSION.to_s
         rescue LoadError
             nil
         end
-    }
+    end
 end
